<?php
class Installer {
	/**
	* Execute the non-interactive installer.
	*
	* @see install_drupal()
	*/
	public function doInstall($rootDir, $settings) {
		// Change the directory to the Drupal root.
		chdir($rootDir);

		// :INFO: smilke@ 20160314: workaround for bug #APSI-250
		if (file_exists($rootDir . '/sites/default/settings.php')) {
			rename($rootDir . '/sites/default/settings.php', $rootDir . '/sites/default/settings.php.bak');
		}

		/**
		 * Global flag to indicate the site is in installation mode.
		 *
		 * The constant is defined using define() instead of const so that PHP
		 * versions prior to 5.3 can display proper PHP requirements instead of causing
		 * a fatal error.
		 */
		define('MAINTENANCE_MODE', 'install');
		require_once $rootDir . '/core/includes/install.core.inc';
		install_drupal($this->installParameters($settings));

		Drupal::configFactory()->getEditable('system.file')->set('path.temporary', 'tmp')->save();
	}

	/**
	* Returns the parameters that will be used when configure script installs Drupal.
	*
	* @see install_drupal()
	* @see install_state_defaults()
	*
	* @return array
	* Array of parameters for use in install_drupal().
	*/
	protected function installParameters($settings) {
		$dbConnection = array(
			'driver' => 'mysql',
			'mysql' => array(
				'database' => $settings['database']['database'],
				'username' => $settings['database']['username'],
				'password' => $settings['database']['password'],
				'prefix' => $settings['database']['prefix'],
				'host' => $settings['database']['host'],
				'port' => $settings['database']['port'],
			),
		);
    
		$parameters = array(
			'interactive' => false,
			'download_translation' => true,
			'parameters' => array(
				'profile' => 'standard',
				'langcode' => 'en',
			),
			'forms' => array(
			'install_settings_form' => $dbConnection,
			'install_configure_form' => array(
				'site_name' => $settings['site']['name'],
				'site_mail' => $settings['site']['mail'],
				'account' => array(
					'name' => $settings['admin']['name'],
					'mail' => $settings['admin']['mail'],
					'pass' => array(
						'pass1' => $settings['admin']['password'],
						'pass2' => $settings['admin']['password'],
					),
				),
				// \Drupal\Core\Render\Element\Checkboxes::valueCallback() requires
				// NULL instead of FALSE values for programmatic form submissions to
				// disable a checkbox.
				'update_status_module' => array(
					1 => NULL,
					2 => NULL,
				),
			),
			),
		);
    
		return $parameters;
	}
}